@@ -1,9 +1,12 @@
-from openshift.dynamic.exceptions import NotFoundError
-
+from ocp_resources.constants import NOT_FOUND_ERROR_EXCEPTION_DICT
+from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class Benchmark(NamespacedResource):
     """
     Benchmark resource
@@ -39,7 +42,7 @@ class Benchmark(NamespacedResource):
             wait_timeout=30,
             sleep=1,
             func=lambda: getattr(self.instance, parent, None),
-            exceptions=NotFoundError,
+            exceptions_dict=NOT_FOUND_ERROR_EXCEPTION_DICT,
         )
         for sample in samples:
             if sample:
